/******************************************************************************
* File Name: main.c
*  Version 3.0
*
* Description:
*  main file
* 
* Note:
*
********************************************************************************
* Copyright (2018), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/

/*******************************************************************************
*  Project Name: CE210383_PSoC3_5_RTD
*  Device Tested: CY8C3866AXI, CY8C5588AXI
*  Software Version: PSoC Creator 4.2
*  Compilers Tested: KEIL, ARM GCC
*  Related Hardware: CY8CKIT-030, CY8CKIT-050, CY8CKIT-025
*******************************************************************************
*******************************************************************************/

/* Project Description:
* This code example measures RTD temperature and reports result on LCD and over UART.
***************************************************************************** */
#include "removeOffsetNoise.h"
#include "getResistance.h"
#include <stdio.h>

int main(void)
{
   	/* Calculated RTD resistance */
	int32 rtdRes = 0;
    
    /* Calculated temperature in 1/100th of degree Celsius using RTD sensor resistance */
    int32 rtdTemp = 0;
	
	/* Voltage(ADC counts) across reference resistance */
	int32 vRef;
    
    /*Decimal Temp*/
    int32 decTemp;
    
    /*Fractional Temp*/
    int32 fracTemp;
    
	/* LCD display variable */
	char printBuf[16]={'\0'};
    
    CyGlobalIntEnable;
	
	/* Start LCD, ADC and IDAC; Initialize LCD */
	LCD_Start();
    LCD_Position(0,0);
    LCD_PrintString("RTD Temperature");
	ADCMux_Start();
    CurrentMux_Start();
	ADC_Start();
	IDAC_Start();
    UART_Start();
	
	for(;;)
	{
		/* Measure the voltage across reference resistance */
		vRef = MeasureRefResVoltage();
		
		/* Find the RTD resistance */
		rtdRes = GetRTDRes(vRef);
		
		/* Calculate RTD temperature from resistance */
		rtdTemp = RTD_GetTemperature(rtdRes);
		
        /*Determine decimal portion of temperature by dividing temperature by 100*/
        decTemp = rtdTemp/100;
        
        /*Determine fraction portion of temperature by subtracting decimal portion from result*/
        fracTemp = rtdTemp - (decTemp * 100);
        /*If fractional temperature is negative make it positive*/
        if(fracTemp < 0)
        {
            fracTemp *= -1;
        }
        
        /*format string to print out over UART*/
        sprintf(printBuf, "RTD Temp=%ld.%02ld    ", decTemp, fracTemp); 
		
        /*Print result over UART*/
        UART_PutString(printBuf);
        UART_PutString("\n\r");
        
		/* Display RTD temperature */
		LCD_Position(1,0);
		
        /*Print out temperature*/
		LCD_PrintString(printBuf);
	}
}

/* [] END OF FILE */
